@@ -24,7 +24,7 @@ class ReplicaClient(BaseClient):
     def __init__(self, rucio_host=None, auth_host=None, account=None, ca_cert=None, auth_type=None, creds=None, timeout=None):
         super(ReplicaClient, self).__init__(rucio_host, auth_host, account, ca_cert, auth_type, creds, timeout)
 
-    def declare_bad_file_replicas(self, pfns, rse, session=None):
+    def declare_bad_file_replicas(self, pfns, rse):
         """
         Declare a list of bad replicas.
 
@@ -37,7 +37,7 @@ class ReplicaClient(BaseClient):
         r = self._send_request(url, headers=headers, type='POST', data=dumps(data))
         if r.status_code == codes.created:
             return True
-        exc_cls, exc_msg = self._get_exception(r.headers)
+        exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code)
         raise exc_cls(exc_msg)
 
     def get_did_from_pfns(self, pfns, rse):
@@ -54,7 +54,7 @@ class ReplicaClient(BaseClient):
         r = self._send_request(url, headers=headers, type='POST', data=dumps(data))
         if r.status_code == codes.ok:
             return self._load_json_data(r)
-        exc_cls, exc_msg = self._get_exception(r.headers)
+        exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code)
         raise exc_cls(exc_msg)
 
     def list_replicas(self, dids, schemes=None, unavailable=False, metalink=None):
@@ -89,7 +89,7 @@ class ReplicaClient(BaseClient):
             if not metalink:
                 return self._load_json_data(r)
             return r.text
-        exc_cls, exc_msg = self._get_exception(r.headers)
+        exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code)
         raise exc_cls(exc_msg)
 
     def add_replica(self, rse, scope, name, bytes, adler32, pfn=None, md5=None, meta={}):
@@ -115,40 +115,42 @@ class ReplicaClient(BaseClient):
             dict['pfn'] = pfn
         return self.add_replicas(rse=rse, files=[dict])
 
-    def add_replicas(self, rse, files):
+    def add_replicas(self, rse, files, ignore_availability=True):
         """
         Bulk add file replicas to a RSE.
 
         :param rse: the RSE name.
         :param files: The list of files. This is a list of DIDs like :
         [{'scope': <scope1>, 'name': <name1>}, {'scope': <scope2>, 'name': <name2>}, ...]
+        :param ignore_availability: Ignore the RSE blacklisting.
 
         :return: True if files were created successfully.
         """
         url = build_url(choice(self.list_hosts), path=self.REPLICAS_BASEURL)
-        data = {'rse': rse, 'files': files}
+        data = {'rse': rse, 'files': files, 'ignore_availability': ignore_availability}
         r = self._send_request(url, type='POST', data=render_json(**data))
         if r.status_code == codes.created:
             return True
-        exc_cls, exc_msg = self._get_exception(r.headers)
+        exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code)
         raise exc_cls(exc_msg)
 
-    def delete_replicas(self, rse, files):
+    def delete_replicas(self, rse, files, ignore_availability=True):
         """
         Bulk delete file replicas from a RSE.
 
         :param rse: the RSE name.
         :param files: The list of files. This is a list of DIDs like :
         [{'scope': <scope1>, 'name': <name1>}, {'scope': <scope2>, 'name': <name2>}, ...]
+        :param ignore_availability: Ignore the RSE blacklisting.
 
         :return: True if files have been deleted successfully.
         """
         url = build_url(choice(self.list_hosts), path=self.REPLICAS_BASEURL)
-        data = {'rse': rse, 'files': files}
+        data = {'rse': rse, 'files': files, 'ignore_availability': ignore_availability}
         r = self._send_request(url, type='DEL', data=render_json(**data))
         if r.status_code == codes.ok:
             return True
-        exc_cls, exc_msg = self._get_exception(r.headers)
+        exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code)
         raise exc_cls(exc_msg)
 
     def update_replicas_states(self, rse, files):
@@ -166,5 +168,5 @@ class ReplicaClient(BaseClient):
         r = self._send_request(url, type='PUT', data=render_json(**data))
         if r.status_code == codes.ok:
             return True
-        exc_cls, exc_msg = self._get_exception(r.headers)
+        exc_cls, exc_msg = self._get_exception(headers=r.headers, status_code=r.status_code)
         raise exc_cls(exc_msg)
