@@ -26,7 +26,7 @@ class RuleClient(BaseClient):
     def __init__(self, rucio_host=None, auth_host=None, account=None, ca_cert=None, auth_type=None, creds=None, timeout=None):
         super(RuleClient, self).__init__(rucio_host, auth_host, account, ca_cert, auth_type, creds, timeout)
 
-    def add_replication_rule(self, dids, copies, rse_expression, weight=None, lifetime=None, grouping='DATASET', account=None, locked=False, source_replica_expression=None):
+    def add_replication_rule(self, dids, copies, rse_expression, weight=None, lifetime=None, grouping='DATASET', account=None, locked=False, source_replica_expression=None, activity=None, notify='N'):
         """
         :param dids:                       The data identifier set.
         :param copies:                     The number of replicas.
@@ -39,13 +39,15 @@ class RuleClient(BaseClient):
         :param account:                    The account owning the rule.
         :param locked:                     If the rule is locked, it cannot be deleted.
         :param source_replica_expression:  RSE Expression for RSEs to be considered for source replicas.
+        :param activity:                   Transfer Activity to be passed to FTS.
+        :param notify:                     Notification setting for the rule (Y, N, C).
         """
         path = self.RULE_BASEURL + '/'
         url = build_url(choice(self.list_hosts), path=path)
         # TODO remove the subscription_id from the client; It will only be used by the core;
         data = dumps({'dids': dids, 'copies': copies, 'rse_expression': rse_expression,
                       'weight': weight, 'lifetime': lifetime, 'grouping': grouping,
-                      'account': account, 'locked': locked, 'source_replica_expression': source_replica_expression})
+                      'account': account, 'locked': locked, 'source_replica_expression': source_replica_expression, 'activity': activity, 'notify': notify})
         r = self._send_request(url, type='POST', data=data)
         if r.status_code == codes.created:
             return loads(r.text)
@@ -85,15 +87,15 @@ class RuleClient(BaseClient):
             exc_cls, exc_msg = self._get_exception(r.headers, r.status_code)
             raise exc_cls(exc_msg)
 
-    def update_lock_state(self, rule_id, lock_state):
+    def update_replication_rule(self, rule_id, options):
         """
-        :param rule_id:  The id of the rule to be retrieved.
-        :param lock_state:   If the rule is locked, it cannot be deleted.
-        :raises:         RuleNotFound
+        :param rule_id:   The id of the rule to be retrieved.
+        :param options:   Options dictionary.
+        :raises:          RuleNotFound
         """
         path = self.RULE_BASEURL + '/' + rule_id
         url = build_url(choice(self.list_hosts), path=path)
-        data = dumps({'locked': lock_state})
+        data = dumps({'options': options})
         r = self._send_request(url, type='PUT', data=data)
         if r.status_code == codes.ok:
             return True
