@@ -12,6 +12,7 @@
 # - Ralph Vigne, <ralph.vigne@cern.ch>, 2012-2013
 # - Martin Barisits, <martin.barisits@cern.ch>, 2012-2014
 # - Cedric Serfon, <cedric.serfon@cern.ch>, 2013-2014
+# - Wen Guan, <wen.guan@cern.ch>, 2014
 
 
 """Exceptions used with Rucio.
@@ -174,6 +175,12 @@ class DuplicateContent(RucioException):
         self._message = "Data identifier already added to the destination content."
 
 
+class DuplicateRule(RucioException):
+    def __init__(self, *args, **kwargs):
+        super(DuplicateRule, self).__init__(args, kwargs)
+        self._message = "A duplicate rule for this account, did, rse_expression, copies already exists."
+
+
 class ErrorLoadingCredentials(RucioException):
     def __init__(self, *args, **kwargs):
         super(ErrorLoadingCredentials, self).__init__(args, kwargs)
@@ -222,6 +229,12 @@ class ReplicaNotFound(RucioException):
         self._message = "Replica not found"
 
 
+class ReplicaUnAvailable(RucioException):
+    def __init__(self, *args, **kwargs):
+        super(ReplicaUnAvailable, self).__init__(args, kwargs)
+        self._message = "Replica unavailable"
+
+
 class ForbiddenSearch(RucioException):
     def __init__(self, *args, **kwargs):
         super(ForbiddenSearch, self).__init__(args, kwargs)
