@@ -7,7 +7,7 @@
 #
 # Authors:
 # - Vincent Garonne, <vincent.garonne@cern.ch>, 2012-2013
-# - Mario Lassnig, <mario.lassnig@cern.ch>, 2013
+# - Mario Lassnig, <mario.lassnig@cern.ch>, 2013-2014
 # - Martin Barisits, <martin.barisits@cern.ch>, 2013-2014
 
 import string
@@ -22,7 +22,7 @@ from rucio.client.didclient import DIDClient
 from rucio.client.ruleclient import RuleClient
 from rucio.client.subscriptionclient import SubscriptionClient
 from rucio.common.utils import generate_uuid as uuid
-from rucio.common.exception import RuleNotFound, AccessDenied, InsufficientAccountLimit
+from rucio.common.exception import RuleNotFound, AccessDenied, InsufficientAccountLimit, DuplicateRule
 from rucio.core.account_counter import get_counter as get_account_counter
 from rucio.daemons.judge.evaluator import re_evaluator
 from rucio.core.did import add_did, attach_dids, set_status
@@ -135,8 +135,22 @@ class TestReplicationRuleCore():
             assert(len(t1.intersection(rse_locks)) == 2)
             assert_not_in(self.rse4_id, rse_locks)
 
+    def test_add_rule_duplicate(self):
+        """ REPLICATION RULE (CORE): Add a replication rule duplicate"""
+        scope = 'mock'
+        files = create_files(3, scope, self.rse1)
+        dataset = 'dataset_' + str(uuid())
+        add_did(scope, dataset, DIDType.from_sym('DATASET'), 'jdoe')
+        attach_dids(scope, dataset, files, 'jdoe')
+
+        # Add a first rule to the DS
+        add_rule(dids=[{'scope': scope, 'name': dataset}], account='jdoe', copies=2, rse_expression=self.T1, grouping='NONE', weight=None, lifetime=None, locked=False, subscription_id=None)
+
+        # Add a second rule and check if the right locks are created
+        assert_raises(DuplicateRule, add_rule, dids=[{'scope': scope, 'name': dataset}], account='jdoe', copies=2, rse_expression=self.T1, grouping='NONE', weight=None, lifetime=None, locked=False, subscription_id=None)
+
     def test_add_rules_datasets_none(self):
-        """ REPLUCATION RULE (CORE): Add replication rules to multiple datasets, NONE Grouping"""
+        """ REPLICATION RULE (CORE): Add replication rules to multiple datasets, NONE Grouping"""
         scope = 'mock'
         files1 = create_files(3, scope, self.rse4)
         dataset1 = 'dataset_' + str(uuid())
@@ -217,7 +231,7 @@ class TestReplicationRuleCore():
             assert(len(first_locks.intersection(rse_locks)) == 2)
 
         # Check if the DatasetLocks are created properly
-        dataset_locks = get_dataset_locks(scope=scope, name=dataset)
+        dataset_locks = [lock for lock in get_dataset_locks(scope=scope, name=dataset)]
         assert(len(t1.intersection(set([lock['rse_id'] for lock in dataset_locks]))) == 2)
         assert(len(first_locks.intersection(set([lock['rse_id'] for lock in dataset_locks]))) == 2)
 
@@ -267,7 +281,7 @@ class TestReplicationRuleCore():
             assert(len(first_locks.intersection(rse_locks)) == 2)
 
         # Check if the DatasetLocks are created properly
-        dataset_locks = get_dataset_locks(scope=scope, name=dataset)
+        dataset_locks = [lock for lock in get_dataset_locks(scope=scope, name=dataset)]
         assert(len(t1.intersection(set([lock['rse_id'] for lock in dataset_locks]))) == 2)
         assert(len(first_locks.intersection(set([lock['rse_id'] for lock in dataset_locks]))) == 2)
 
