@@ -22,6 +22,7 @@ urls = (
     '/accounting', 'Accounting',
     '/did', 'DID',
     '/infrastructure', 'Infrastructure',
+    '/list_rules', 'ListRules',
     '/rse_usage', 'RSEUsage',
     '/rse_locks', 'RSELocks',
     '/rule', 'Rule',
@@ -45,6 +46,12 @@ class DID():
         return check_token(render.did())
 
 
+class ListRules():
+    def GET(self):
+        render = template.render(join(dirname(__file__), 'templates/'))
+        return check_token(render.list_rules())
+
+
 class Rule():
     def GET(self):
         render = template.render(join(dirname(__file__), 'templates/'))
