@@ -69,14 +69,18 @@ function did_search(input) {
             document.location.href = '/search?scope=' + scope + '&name=' + name;
         }
     }
-
-
 }
 
 /* engage */
 var r = new RucioClient(token, account);
 $(document).ready(function() {
-    r.ping({success: function(data) { $('#rucio_server_version').html(data.version);}});
+    r.ping({
+        success: function(data) {
+            $('#rucio_server_version').html(data.version);
+        }, error: function(jqXHR, textStatus, errorThrown) {
+            console.log(textStatus);
+        }
+    });
 
     $('#current_account').text(account);
     available_accounts.forEach(function(acct) {
