@@ -86,6 +86,24 @@ RucioClient.prototype.list_identities = function(options) {
         });
 };
 
+/* list all rules for an account */
+RucioClient.prototype.list_account_rules = function(options) {
+    jQuery.ajax({url: this.url + '/accounts/' + options.account + '/rules',
+                 crossDomain: true,
+                 headers: {'X-Rucio-Auth-Token': this.token,
+                           'X-Rucio-Account': this.account },
+                 dataType: 'text',
+                 success: function(data)
+                 {
+                     options.success(parse_json_stream(data));
+                 },
+                 error: function(jqXHR, textStatus, errorThrown)
+                 {
+                     options.error(jqXHR, textStatus, errorThrown);
+                 }
+        });
+};
+
 /* list all dids for a scope */
 RucioClient.prototype.scope_list = function(options) {
     var url = this.url + '/dids/' + options.scope + '/';
